<?php

namespace Lavalite\Show\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Lavalite\Show\Http\Requests\ShowAdminRequest;
use Lavalite\Show\Interfaces\ShowRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class ShowAdminController extends AdminController
{
    /**
     * Initialize show controller.
     *
     * @param type ShowRepositoryInterface $show
     *
     * @return type
     */
    public function __construct(ShowRepositoryInterface $show)
    {
        $this->model = $show;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ShowAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('show.show.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('show::show.names').' :: ');

        return $this->theme->of('show::admin.show.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ShowAdminRequest $request, $id)
    {
        $show = $this->model->find($id);

        if (empty($show)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('show::admin.show.new');
        }

        if ($request->wantsJson()) {
            return $show;
        }

        Former::populate($show);

        return view('show::admin.show.show', compact('show'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ShowAdminRequest $request)
    {
        $show = $this->model->findOrNew(0);
        Former::populate($show);

        return view('show::admin.show.create', compact('show'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ShowAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $show = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('show::show.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ShowAdminRequest $request, $id)
    {
        $show = $this->model->find($id);

        Former::populate($show);

        return view('show::admin.show.edit', compact('show'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ShowAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $show = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('show::show.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ShowAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('show::show.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
